From 74db831fc8e70215447903420c321805b8bbe0ab Mon Sep 17 00:00:00 2001
From: Marcus Brinkmann <mb@g10code.com>
Date: Fri, 30 Sep 2005 13:24:40 +0000
Subject: [PATCH] doc/ 2005-09-30  Marcus Brinkmann  <marcus@g10code.de>

	* gpgme.texi: Replace plaintext_filename with file_name.

gpgme/
2005-09-30  Marcus Brinkmann  <marcus@g10code.de>

	* decrpyt.c, verify.c, gpgme.h: Replace plaintext_filename with
	file_name.
---
 NEWS            | 51 +++++++++++++++++++++++++++++++++----------------
 doc/ChangeLog   |  2 ++
 doc/gpgme.texi  |  4 ++--
 gpgme/ChangeLog |  5 +++++
 gpgme/decrypt.c |  6 +++---
 gpgme/gpgme.h   | 10 ++++++----
 gpgme/verify.c  |  6 +++---
 7 files changed, 56 insertions(+), 28 deletions(-)

diff --git a/NEWS b/NEWS
index 5c937ffa..df6a5dcc 100644
--- a/NEWS
+++ b/NEWS
@@ -4,22 +4,13 @@ Noteworthy changes in version 1.1.0 (unreleased)
  * You can now configure the backend engine file name and home
    directory to be used, as default and per context.
 
- * Previousy, GPGME would use a default "include certs" of 1.  This
-   has been changed.  Now GPGME will use the crypto backend engines
-   default unless you set the value with gpgme_set_include_certs()
-   explicitely.  A new macro GPGME_INCLUDE_CERTS_DEFAULT can be used
-   as a value to explicitely request the new default behaviour.
-
-   Because the default changes, this is a slight change of the API
-   semantics.  We consider it to be a bug fix.
-
  * Information about the recipients of an encrypted text is now
    available at decryption time.
 
  * New status GPGME_STATUS_PLAINTEXT.  This is analyzed by the decrypt
    and verify handlers, the information about the plaintext filename,
-   if available is made available in the new field plaintext_filename
-   of the respective result structure.
+   if available is made available in the new field file_name of the
+   respective result structure.
 
  * The code for "automagically detecting the thread library" has been
    removed from libgpgme.  It is deprecated since version 0.4.3.
@@ -37,24 +28,52 @@ Noteworthy changes in version 1.1.0 (unreleased)
    delimiter.  The standard install directory is used when locating
    gpg or gpgsm before finally falling back to the hardwired name.
 
+ * There is a new flag for keys and subkeys, is_qualified, which
+   indicates if a key can be used for qualified signatures according
+   to local government regulations.
+
+ * Interface changes relative to the 1.0.3 release:
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 gpgme_set_engine_info		NEW
 gpgme_ctx_get_engine_info	NEW
 gpgme_ctx_set_engine_info	NEW
-gpgme_set_include_certs		CHANGED DEFAULT
-GPGME_INCLUDE_CERTS_DEFAULT	NEW
 gpgme_recipient_t		NEW
 gpgme_decrypt_result_t		EXTENDED: New field recipients.
 gpgme_verify_result_t		EXTENDED: New fields pubkey_algo, hash_algo.
+gpgme_decrypt_result_t		EXTENDED: New field file_name.
+gpgme_verify_result_t		EXTENDED: New field file_name.
+GPGME_STATUS_PLAINTEXT		NEW
+gpgme_key_t			EXTENDED: New field is_qualified.
+gpgme_subkey_t			EXTENDED: New field is_qualified.
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+
+Noteworthy changes in version 1.0.3 (2005-06-20)
+------------------------------------------------
+
+ * Previousy, GPGME would use a default "include certs" of 1.  This
+   has been changed.  Now GPGME will use the crypto backend engines
+   default unless you set the value with gpgme_set_include_certs()
+   explicitely.  A new macro GPGME_INCLUDE_CERTS_DEFAULT can be used
+   as a value to explicitely request the new default behaviour.
+
+   Because the default changes, this is a slight change of the API
+   semantics.  We consider it to be a bug fix.
+
+ * A bug which made GPGME hang has been fixed.  If you have
+   experienced hanging before, please try out this version and let me
+   know if you still experience hanging problems.
+
+ * Interface changes relative to the 0.9.0 release:
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+gpgme_set_include_certs		CHANGED DEFAULT
+GPGME_INCLUDE_CERTS_DEFAULT	NEW
 GPGME_STATUS_SIG_SUBPACKET	NEW
 GPGME_STATUS_NEED_PASSPHRASE_PIN NEW
 GPGME_STATUS_SC_OP_FAILURE	NEW
 GPGME_STATUS_SC_OP_SUCCESS	NEW
 GPGME_STATUS_CARDCTRL		NEW
 GPGME_STATUS_BACKUP_KEY_CREATED	NEW
-gpgme_decrypt_result_t		EXTENDED: New field plaintext_filename.
-gpgme_verify_result_t		EXTENDED: New field plaintext_filename.
-GPGME_STATUS_PLAINTEXT		NEW
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 
diff --git a/doc/ChangeLog b/doc/ChangeLog
index f7741e8f..46ee86e1 100644
--- a/doc/ChangeLog
+++ b/doc/ChangeLog
@@ -1,5 +1,7 @@
 2005-09-30  Marcus Brinkmann  <marcus@g10code.de>
 
+	* gpgme.texi: Replace plaintext_filename with file_name.
+
 	* gpgme.texi (Key Management): Document is_qualified.
 
 2005-07-27  Marcus Brinkmann  <marcus@g10code.de>
diff --git a/doc/gpgme.texi b/doc/gpgme.texi
index afe375b2..e0f7b770 100644
--- a/doc/gpgme.texi
+++ b/doc/gpgme.texi
@@ -3677,7 +3677,7 @@ This is true if the key was not used according to its policy.
 @item gpgme_recipient_t recipient
 This is a linked list of recipients to which this message was encrypted.
 
-@item char *plaintext_filename
+@item char *file_name
 This is the filename of the original plaintext message file if it is
 known, otherwise this is a null pointer.
 @end table
@@ -3893,7 +3893,7 @@ a @code{NULL} pointer.  The structure contains the following member:
 A linked list with information about all signatures for which a
 verification was attempted.
 
-@item char *plaintext_filename
+@item char *file_name
 This is the filename of the original plaintext message file if it is
 known, otherwise this is a null pointer.
 @end table
diff --git a/gpgme/ChangeLog b/gpgme/ChangeLog
index efc57e99..71d02e98 100644
--- a/gpgme/ChangeLog
+++ b/gpgme/ChangeLog
@@ -1,3 +1,8 @@
+2005-09-30  Marcus Brinkmann  <marcus@g10code.de>
+
+	* decrpyt.c, verify.c, gpgme.h: Replace plaintext_filename with
+	file_name.
+
 2005-09-29  Marcus Brinkmann  <marcus@g10code.de>
 
 	* gpgme.h (struct _gpgme_key): Add field is_qualified.
diff --git a/gpgme/decrypt.c b/gpgme/decrypt.c
index 91e6c305..5ce21bad 100644
--- a/gpgme/decrypt.c
+++ b/gpgme/decrypt.c
@@ -54,8 +54,8 @@ release_op_data (void *hook)
   if (opd->result.unsupported_algorithm)
     free (opd->result.unsupported_algorithm);
 
-  if (opd->result.plaintext_filename)
-    free (opd->result.plaintext_filename);
+  if (opd->result.file_name)
+    free (opd->result.file_name);
 }
 
 
@@ -242,7 +242,7 @@ _gpgme_decrypt_status_handler (void *priv, gpgme_status_code_t code,
       break;
 
     case GPGME_STATUS_PLAINTEXT:
-      err = _gpgme_parse_plaintext (args, &opd->result.plaintext_filename);
+      err = _gpgme_parse_plaintext (args, &opd->result.file_name);
       if (err)
 	return err;
       
diff --git a/gpgme/verify.c b/gpgme/verify.c
index 52f700b2..90b4cf89 100644
--- a/gpgme/verify.c
+++ b/gpgme/verify.c
@@ -71,8 +71,8 @@ release_op_data (void *hook)
       sig = next;
     }
 
-  if (opd->result.plaintext_filename)
-    free (opd->result.plaintext_filename);
+  if (opd->result.file_name)
+    free (opd->result.file_name);
 }
 
 
@@ -699,7 +699,7 @@ _gpgme_verify_status_handler (void *priv, gpgme_status_code_t code, char *args)
       break;
 
     case GPGME_STATUS_PLAINTEXT:
-      err = _gpgme_parse_plaintext (args, &opd->result.plaintext_filename);
+      err = _gpgme_parse_plaintext (args, &opd->result.file_name);
       if (err)
 	return err;
diff --git a/gpgme/gpgme.h b/gpgme/gpgme.h
index 56871715..be75e724 100644
--- a/gpgme/gpgme.h
+++ b/gpgme/gpgme.h
@@ -1119,8 +1119,9 @@ struct _gpgme_op_decrypt_result
 
   gpgme_recipient_t recipients;
 
-  /* The original filename of the plaintext message, if available.  */
-  char *plaintext_filename;
+  /* The original file name of the plaintext message, if
+     available.  */
+  char *file_name;
 };
 typedef struct _gpgme_op_decrypt_result *gpgme_decrypt_result_t;
 
@@ -1271,8 +1272,9 @@ struct _gpgme_op_verify_result
 {
   gpgme_signature_t signatures;
 
-  /* The original filename of the plaintext message, if available.  */
-  char *plaintext_filename;
+  /* The original file name of the plaintext message, if
+     available.  */
+  char *file_name;
 };
 typedef struct _gpgme_op_verify_result *gpgme_verify_result_t;
 